pub struct CommandBufferFlags(/* private fields */);Implementations
Sourceimpl CommandBufferFlags
impl CommandBufferFlags
Sourcepub const VENDOR_FLAG_0: CommandBufferFlags
pub const VENDOR_FLAG_0: CommandBufferFlags
Vendor specific definitions start here
Sourceimpl CommandBufferFlags
impl CommandBufferFlags
Sourcepub const fn empty() -> CommandBufferFlags
pub const fn empty() -> CommandBufferFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> CommandBufferFlags
pub const fn all() -> CommandBufferFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<CommandBufferFlags>
pub const fn from_bits(bits: u64) -> Option<CommandBufferFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> CommandBufferFlags
pub const fn from_bits_truncate(bits: u64) -> CommandBufferFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> CommandBufferFlags
pub const fn from_bits_retain(bits: u64) -> CommandBufferFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CommandBufferFlags>
pub fn from_name(name: &str) -> Option<CommandBufferFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CommandBufferFlags) -> bool
pub const fn intersects(&self, other: CommandBufferFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: CommandBufferFlags) -> bool
pub const fn contains(&self, other: CommandBufferFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: CommandBufferFlags)
pub fn insert(&mut self, other: CommandBufferFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: CommandBufferFlags)
pub fn remove(&mut self, other: CommandBufferFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CommandBufferFlags)
pub fn toggle(&mut self, other: CommandBufferFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: CommandBufferFlags, value: bool)
pub fn set(&mut self, other: CommandBufferFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CommandBufferFlags) -> CommandBufferFlags
pub const fn intersection(self, other: CommandBufferFlags) -> CommandBufferFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: CommandBufferFlags) -> CommandBufferFlags
pub const fn union(self, other: CommandBufferFlags) -> CommandBufferFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: CommandBufferFlags) -> CommandBufferFlags
pub const fn difference(self, other: CommandBufferFlags) -> CommandBufferFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: CommandBufferFlags,
) -> CommandBufferFlags
pub const fn symmetric_difference( self, other: CommandBufferFlags, ) -> CommandBufferFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> CommandBufferFlags
pub const fn complement(self) -> CommandBufferFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CommandBufferFlags
impl CommandBufferFlags
Sourcepub const fn iter(&self) -> Iter<CommandBufferFlags> ⓘ
pub const fn iter(&self) -> Iter<CommandBufferFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CommandBufferFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<CommandBufferFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CommandBufferFlags
impl CommandBufferFlags
pub fn from_bits_allow_unknown(bits: u64) -> CommandBufferFlags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u64