pub struct ImportFlags(/* private fields */);Implementations
Sourceimpl ImportFlags
impl ImportFlags
pub const SEMAPHORE_ONE_SHOT: ImportFlags
Sourceimpl ImportFlags
impl ImportFlags
Sourcepub const fn empty() -> ImportFlags
pub const fn empty() -> ImportFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ImportFlags
pub const fn all() -> ImportFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<ImportFlags>
pub const fn from_bits(bits: u64) -> Option<ImportFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> ImportFlags
pub const fn from_bits_truncate(bits: u64) -> ImportFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> ImportFlags
pub const fn from_bits_retain(bits: u64) -> ImportFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ImportFlags>
pub fn from_name(name: &str) -> Option<ImportFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ImportFlags) -> bool
pub const fn intersects(&self, other: ImportFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ImportFlags) -> bool
pub const fn contains(&self, other: ImportFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ImportFlags)
pub fn insert(&mut self, other: ImportFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ImportFlags)
pub fn remove(&mut self, other: ImportFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ImportFlags)
pub fn toggle(&mut self, other: ImportFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ImportFlags, value: bool)
pub fn set(&mut self, other: ImportFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ImportFlags) -> ImportFlags
pub const fn intersection(self, other: ImportFlags) -> ImportFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ImportFlags) -> ImportFlags
pub const fn union(self, other: ImportFlags) -> ImportFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ImportFlags) -> ImportFlags
pub const fn difference(self, other: ImportFlags) -> ImportFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ImportFlags) -> ImportFlags
pub const fn symmetric_difference(self, other: ImportFlags) -> ImportFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ImportFlags
pub const fn complement(self) -> ImportFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ImportFlags
impl ImportFlags
Sourcepub const fn iter(&self) -> Iter<ImportFlags> ⓘ
pub const fn iter(&self) -> Iter<ImportFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ImportFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<ImportFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ImportFlags
impl ImportFlags
pub fn from_bits_allow_unknown(bits: u64) -> ImportFlags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u64