pub struct PowerServiceMarker;Trait Implementations
Sourceimpl Clone for PowerServiceMarker
impl Clone for PowerServiceMarker
Sourcefn clone(&self) -> PowerServiceMarker
fn clone(&self) -> PowerServiceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PowerServiceMarker
Sourceimpl Debug for PowerServiceMarker
impl Debug for PowerServiceMarker
impl Eq for PowerServiceMarker
Sourceimpl Hash for PowerServiceMarker
impl Hash for PowerServiceMarker
Sourceimpl Ord for PowerServiceMarker
impl Ord for PowerServiceMarker
Sourcefn cmp(&self, other: &PowerServiceMarker) -> Ordering
fn cmp(&self, other: &PowerServiceMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PowerServiceMarker
impl PartialEq for PowerServiceMarker
Sourcefn eq(&self, other: &PowerServiceMarker) -> bool
fn eq(&self, other: &PowerServiceMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PowerServiceMarker
impl PartialOrd for PowerServiceMarker
Sourceimpl ServiceMarker for PowerServiceMarker
Available on Fuchsia only.
impl ServiceMarker for PowerServiceMarker
Available on Fuchsia only.
Sourceconst SERVICE_NAME: &'static str = "fuchsia.gpu.magma.PowerService"
const SERVICE_NAME: &'static str = "fuchsia.gpu.magma.PowerService"
The name of the service. Used for service lookup and discovery.
Sourcetype Proxy = PowerServiceProxy
type Proxy = PowerServiceProxy
The type of the proxy object upon which calls are made to a remote FIDL service.
Sourcetype Request = PowerServiceRequest
type Request = PowerServiceRequest
The request type for this particular FIDL service.
impl StructuralPartialEq for PowerServiceMarker